# Higher-Order Functions

JAX has a number of higher order functions (e.g. [jax.vmap][], [jax.lax.scan][]) that correspond to traditional
functional programming concepts. Haliax provides named versions of these functions that operate on named arrays/named
axes.

## Vectorization

::: haliax.vmap


## Looping and Scanning

::: haliax.fold
::: haliax.scan
::: haliax.map
